==> 0.5.6.tar.gz: lib/widget/vgk-sub-title-widget/vgk-sub-title-widget-with-animation.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkSubTitleWithAnimationWidget extends StatelessWidget {
  final String titleTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  const VgkSubTitleWithAnimationWidget({
    Key key,
    this.titleTxt: "",
    this.animationController,
    this.animation,
    this.color,
    this.titlefontSize,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Container(
              child: Padding(
                padding: const EdgeInsets.only(
                  left: VgkProGamingTheme.paddingDoubleExtraLarge,
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Row(
                  children: <Widget>[
                    Expanded(
                      child: Text(
                        titleTxt,
                        textAlign: TextAlign.left,
                        style: titlefontSize != null
                            ? titlefontSize
                            : VgkProGamingTheme.h2,
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}

==> 0.9.5.tar.gz: lib/widget/vgk-sub-title-widget/vgk-sub-title-widget-with-animation.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkSubTitleWithAnimationWidget extends StatelessWidget {
  final String titleTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  final String primaryColor;
  const VgkSubTitleWithAnimationWidget(
      {Key key,
      this.titleTxt: "",
      this.animationController,
      this.animation,
      this.color,
      this.titlefontSize,
      this.primaryColor})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Container(
              child: Padding(
                padding: const EdgeInsets.only(
                  left: VgkProGamingTheme.paddingDoubleExtraLarge,
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Row(
                  children: <Widget>[
                    Expanded(
                      child: Text(
                        titleTxt,
                        textAlign: TextAlign.left,
                        style: titlefontSize != null
                            ? titlefontSize
                            : VgkProGamingTheme.h2(primaryColor),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
